@@ -28,13 +28,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QMimeDatabase>
 
 // KDE
-#include <KFileDialog>
+#include <QFileDialog>
 #include <KColorScheme>
 #include <KIO/StatJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KStandardDirs>
 
 // Local
 #include <lib/binder.h>
@@ -68,19 +67,17 @@ struct GvCorePrivate
 
     bool showSaveAsDialog(const QUrl &url, QUrl* outUrl, QByteArray* format)
     {
-        KFileDialog dialog(url, QString(), mMainWindow);
-        dialog.setOperationMode(KFileDialog::Saving);
-        dialog.setSelection(url.fileName());
+        QFileDialog dialog(mMainWindow);
+        dialog.setAcceptMode(QFileDialog::AcceptSave);
+        dialog.selectUrl(url);
 
         QStringList supportedMimetypes;
         for (const QByteArray &mimeName : QImageWriter::supportedMimeTypes()) {
             supportedMimetypes.append(QString::fromLocal8Bit(mimeName));
         }
 
-        dialog.setMimeFilter(
-            supportedMimetypes,
-            MimeTypeUtils::urlMimeType(url)         // Default
-        );
+        dialog.setMimeTypeFilters(supportedMimetypes);
+        dialog.selectMimeTypeFilter(MimeTypeUtils::urlMimeType(url));
 
         // Show dialog
         do {
@@ -88,29 +85,26 @@ struct GvCorePrivate
                 return false;
             }
 
-            const QString mimeType = dialog.currentMimeFilter();
-            if (mimeType.isEmpty()) {
-                KMessageBox::sorry(
-                    mMainWindow,
-                    i18nc("@info",
-                          "No image format selected.")
-                );
-                continue;
+            QList<QUrl> files = dialog.selectedUrls();
+            if (files.isEmpty()) {
+                return false;
             }
 
-            const QStringList typeList = QMimeDatabase().mimeTypeForName(mimeType).suffixes();
-            if (typeList.count() > 0) {
-                *format = typeList[0].toAscii();
+            QString filename = files.first().fileName();
+
+            const QMimeType mimeType = QMimeDatabase().mimeTypeForFile(filename, QMimeDatabase::MatchExtension);
+            if (mimeType.isValid()) {
+                *format = mimeType.preferredSuffix().toLocal8Bit();
                 break;
             }
             KMessageBox::sorry(
                 mMainWindow,
                 i18nc("@info",
-                      "Gwenview cannot save images as %1.", mimeType)
+                      "Gwenview cannot save images as %1.", QFileInfo(filename).suffix())
             );
         } while (true);
 
-        *outUrl = dialog.selectedUrl();
+        *outUrl = dialog.selectedUrls().first();
         return true;
     }
 
@@ -133,19 +127,19 @@ struct GvCorePrivate
         QString name = GwenviewConfig::fullScreenColorScheme();
         if (name.isEmpty()) {
             // Default color scheme
-            QString path = KStandardDirs::locate("data", "gwenview/color-schemes/fullscreen.colors");
+            QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "color-schemes/fullscreen.colors");
             config = KSharedConfig::openConfig(path);
         } else if (name.contains('/')) {
             // Full path to a .colors file
             config = KSharedConfig::openConfig(name);
         } else {
             // Standard KDE color scheme
-            config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, QStandardPaths::DataLocation);
+            config = KSharedConfig::openConfig(QString("color-schemes/%1.colors").arg(name), KConfig::FullConfig, QStandardPaths::AppDataLocation);
         }
         mPalettes[GvCore::FullScreenPalette] = KColorScheme::createApplicationPalette(config);
 
         pal = mPalettes[GvCore::FullScreenPalette];
-        QString path = KStandardDirs::locate("data", "gwenview/images/background.png");
+        QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "images/background.png");
         QPixmap bgTexture(path);
         pal.setBrush(QPalette::Base, bgTexture);
         mPalettes[GvCore::FullScreenViewPalette] = pal;
@@ -176,7 +170,7 @@ GvCore::~GvCore()
 QAbstractItemModel* GvCore::recentFoldersModel() const
 {
     if (!d->mRecentFoldersModel) {
-        d->mRecentFoldersModel = new HistoryModel(const_cast<GvCore*>(this), KStandardDirs::locateLocal("appdata", "recentfolders/"));
+        d->mRecentFoldersModel = new HistoryModel(const_cast<GvCore*>(this), QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "recentfolders/"));
     }
     return d->mRecentFoldersModel;
 }
@@ -284,7 +278,7 @@ void GvCore::saveAs(const QUrl &url)
     KJob* job = doc->save(saveAsUrl, format.data());
     if (!job) {
         const QString name = saveAsUrl.fileName().isEmpty() ? saveAsUrl.toDisplayString() : saveAsUrl.fileName();
-        const QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br>%2",
+        const QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br />%2",
                                    name, doc->errorString());
         KMessageBox::sorry(QApplication::activeWindow(), msg);
     } else {
@@ -307,7 +301,7 @@ void GvCore::slotSaveResult(KJob* _job)
 
     if (job->error()) {
         QString name = newUrl.fileName().isEmpty() ? newUrl.toDisplayString() : newUrl.fileName();
-        QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br>%2",
+        QString msg = xi18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br />%2",
                              name, job->errorString());
 
         int result = KMessageBox::warningContinueCancel(
